# invoice_schema

In `invoice_schema`, models for validators used in RDE's invoice.schema.json are defined.

## InvoiceSchemaJson

::: src.rdetoolkit.models.invoice_schema.InvoiceSchemaJson

### Properties

::: src.rdetoolkit.models.invoice_schema.Properties

### DatasetId

::: src.rdetoolkit.models.invoice_schema.DatasetId

### BasicItems

::: src.rdetoolkit.models.invoice_schema.BasicItems

### BasicItemsValue

::: src.rdetoolkit.models.invoice_schema.BasicItemsValue

### SampleField

::: src.rdetoolkit.models.invoice_schema.SampleField

### SampleProperties

::: src.rdetoolkit.models.invoice_schema.SampleProperties

### SamplePropertiesWhenAdding

::: src.rdetoolkit.models.invoice_schema.SamplePropertiesWhenAdding

### SpecificAttribute

::: src.rdetoolkit.models.invoice_schema.SpecificAttribute

### SampleSpecificItems

::: src.rdetoolkit.models.invoice_schema.SampleSpecificItems

### SpecificProperty

::: src.rdetoolkit.models.invoice_schema.SpecificProperty

### SpecificChildProperty

::: src.rdetoolkit.models.invoice_schema.SpecificChildProperty

### GeneralAttribute

::: src.rdetoolkit.models.invoice_schema.GeneralAttribute

### SampleGeneralItems

::: src.rdetoolkit.models.invoice_schema.SampleGeneralItems

### GeneralProperty

::: src.rdetoolkit.models.invoice_schema.GeneralProperty

### GeneralChildProperty

::: src.rdetoolkit.models.invoice_schema.GeneralChildProperty

### ClassId

::: src.rdetoolkit.models.invoice_schema.ClassId

### TermId

::: src.rdetoolkit.models.invoice_schema.TermId

### CustomField

::: src.rdetoolkit.models.invoice_schema.CustomField

### CustomItems

::: src.rdetoolkit.models.invoice_schema.CustomItems

### MetaProperty

::: src.rdetoolkit.models.invoice_schema.MetaProperty

### Options

::: src.rdetoolkit.models.invoice_schema.Options

### Placeholder

::: src.rdetoolkit.models.invoice_schema.Placeholder

### LangLabels

::: src.rdetoolkit.models.invoice_schema.LangLabels
